hyperspy Package
================

:mod:`hyperspy` Package
-----------------------

.. automodule:: hyperspy.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Release` Module
---------------------

.. automodule:: hyperspy.Release
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`axes` Module
------------------

.. automodule:: hyperspy.axes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`component` Module
-----------------------

.. automodule:: hyperspy.component
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`decorators` Module
------------------------

.. automodule:: hyperspy.decorators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`defaults_parser` Module
-----------------------------

.. automodule:: hyperspy.defaults_parser
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`exceptions` Module
------------------------

.. automodule:: hyperspy.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`experiments` Module
-------------------------

.. automodule:: hyperspy.experiments
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hspy` Module
------------------

.. automodule:: hyperspy.hspy
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`io` Module
----------------

.. automodule:: hyperspy.io
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`messages` Module
----------------------

.. automodule:: hyperspy.messages
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`model` Module
-------------------

.. automodule:: hyperspy.model
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`signal` Module
--------------------

.. automodule:: hyperspy.signal
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    hyperspy.components
    hyperspy.drawing
    hyperspy.gui
    hyperspy.io_plugins
    hyperspy.learn
    hyperspy.misc
    hyperspy.models
    hyperspy.signals
    hyperspy.tests

